@@ -79,6 +79,7 @@ sub _execFilter {
 
 	foreach my $key ( keys %{ $this->{_filters} } ) {
 		my @values = $form->getValues($key);
+		my $empty_exists = !@values && $form->exists($key);
 		foreach my $filter ( @{ $this->{_filters}->{$key} } ) {
 #			my $diag = do
 #			{
@@ -115,7 +116,11 @@ sub _execFilter {
 			}
 			last;
 		}
-		$form->set($key => \@values) if $allowmodify;
+		if( $allowmodify )
+		{
+			# @values が空の時は削除される.
+			$form->set($key => \@values);
+		}
 	}
 	if( $error && $onfail )
 	{
@@ -384,7 +389,13 @@ Shift-Jisでのバイト数の範囲が指定値以内かチェックする。
 
 =item Portable
 
-機種依存文字以外を含んでいないかチェックする。
+機種依存文字を含んでいないかチェックする。
+
+値が空（存在しないか0文字）なら検証OKとなる。
+
+=item PcPortable
+
+携帯絵文字を含んでいないかチェックする。
 
 値が空（存在しないか0文字）なら検証OKとなる。
 
@@ -520,6 +531,14 @@ L<Tripletail::Value/forceMaxSjisLen($max)>。
 最大文字数を指定。超える場合はその文字数以下までカットする。
 L<Tripletail::Value/forceMaxCharLen($max)>。
 
+=item ForcePortable
+
+機種依存文字以外を削除。
+
+=item ForcePcPortable
+
+携帯絵文字以外を削除。
+
 =item TrimWhitespace
 
 値の前後に付いている半角/全角スペース、タブを削除する。
